@@ -1,4 +1,4 @@
-#' Plots of survivor functions.
+#' Plots of hazdata objects.
 #' 
 #' Baseline hazards estimates.
 #' 
@@ -6,35 +6,45 @@
 #' given that it contains a component of type "hazdata".
 #' 
 #' @param x A \code{hazdata} object, typically the 'hazards' element in the
-#' output from \code{link{coxreg}} with \code{hazards = TRUE}.
+#' output from \code{link{coxreg}} with \code{method = "ml"} or 
+#' \code{method = "mppl"} or \code{coxph = FALSE}.
 #' @param strata Stratum names if there are strata present.
-#' @param fn Which type of plot?
+#' @param fn Which type of plot? Allowed values are "cum" (or "cumhaz"),
+#' "surv" (or "sur"), "log", or "loglog". The last two plots the cumulative 
+#' hazards on a log (y) scale or a log-log (xy) scale, respectively. 
 #' @param fig Should a plot actually be produced? Default is TRUE.
 #' @param xlim Horizontal plot limits. If NULL, calculated by the function.
-#' @param ylim Vertical plot limits. If NULL, set to \code{c(0, 1)}
+#' @param ylim Vertical plot limits. If NULL, set to \code{c(0, 1)} for a 
+#' plot of the survival function.
 #' @param main A heading for the plot.
 #' @param xlab Label on the x axis.
 #' @param ylab Label on the y-axis.
 #' @param col Color of the lines. May be a vector of length equal to No. of
 #' strata.
 #' @param lty Line type(s). May be a vector of length equal to No. of strata.
-#' @param printLegend Logical; should a legend be produced?  Defaults to TRUE.
-#' @param where Where should the legend be placed (if(printLegend))?  If
-#' \code{NULL}, "bottomleft" for fn = "surv", otherwise "bottomright".
+#' @param printLegend Logical or character; should a legend be produced?  
+#' Defaults to TRUE. If character, it should be one of \code{bottomleft}, 
+#' \code{bottomright}, etc, see \code{\link{legend}}.
 #' @param ... Anything that \code{\link[graphics]{plot.default}} likes...
 #' @return A list where the elements are two-column matrices, one for each
 #' stratum in the model. The first column contains risktimes, and the second
 #' the y coordinates for the requested curve(s).
+#' @note \code{x} is a list where each element is a two-column matrix. The first
+#'  column contains failure times, and the second column contains the 
+#'  corresponding 'hazard atoms'. 
 #' @author Göran Broström
 #' @keywords survival
 #' @examples
 #' 
 #' time0 <- numeric(50)
 #' group <- c(rep(0, 25), rep(1, 25))
+#' x <- runif(50, -0.5, 0.5)
 #' time1 <- rexp( 50, exp(group) )
 #' event <- rep(1, 50)
-#' fit <- coxreg(Surv(time0, time1, event) ~ strata(group), hazards = TRUE)
-#' plot(fit$hazards)
+#' fit <- coxreg(Surv(time0, time1, event) ~ x + strata(group), method = "ml")
+#' plot(fit$hazards, col = 1:2, fn = "surv", xlab = "Duration")
+#' ## Same result as:
+#' ## plot(fit, col = 1:2, fn = "sur", xlab = "Duration")
 #' 
 #' @export
 plot.hazdata <- function(x, strata = NULL,
@@ -43,24 +53,30 @@ plot.hazdata <- function(x, strata = NULL,
                          xlim = NULL,
                          ylim = NULL,
                          main = NULL,
-                         xlab = NULL,
-                         ylab = NULL,
+                         xlab = "",
+                         ylab = "",
                          col = "black",
                          lty = 1,      # Jan 17, 2014.
-                         printLegend = TRUE, # Jan 17, 2014.
-                         where = NULL,
+                         printLegend = TRUE, # Jul 3, 2020
                          ...
                          ){
     ## Added 7 dec 2013: col.
     ## x is of type 'hazdata', which is a list with two-column matrices
     ## as components, one component per stratum. The first column contains
     ## risktimes, and the second column the corresponding 'hazard atoms'.
-    if (is.null(where)){ # To print 'legend', if any.
-        if (fn[1] == "surv"){
+    if (!inherits(x, "hazdata")) stop("Only for 'hazdata' objects.")
+    where <- "topleft"
+    if (is.logical(printLegend) && printLegend){
+        if (fn[1] %in% c("surv", "sur")){
             where <- "bottomleft"
         }else{
-            where <- "bottomright"
+            where <- "topleft"
         }
+    }else if (is.character(printLegend)){
+        where <- printLegend
+        printLegend <- TRUE
+    }else if (!is.logical(printLegend)){
+        stop("Wrong value to 'printLegend'")
     }
 
     if (!(where %in% c("bottomleft", "bottomright", "topleft", "topright",
@@ -72,28 +88,40 @@ plot.hazdata <- function(x, strata = NULL,
         return(NULL)
     }
         
-    if (!inherits(x, "hazdata")){
-        if (!inherits(x, "coxreg")){
-            stop("First argument must be of type 'hazdata' or 'coxreg'")
-        }else{
-            y <- x
-            x <- x$hazards
-            if (is.null(x)) stop("No 'hazards' component present")
-        }
-    }
+    # if (!inherits(x, "hazdata")){
+    #     if (!inherits(x, "coxreg")){
+    #         stop("First argument must be of type 'hazdata' or 'coxreg'")
+    #     }else{
+    #         y <- x
+    #         x <- x$hazards
+    #         if (is.null(x)) stop("No 'hazards' component present")
+    #     }
+    # }
     fn <- fn[1]
-
+    
+    if (fn == "sur"){
+        fn <- "surv"
+    }else{
+        if (fn == "cumhaz") fn <- "cum"
+    }
     if (!(fn %in% c("cum", "surv", "log", "loglog")))
         stop(paste(fn, "is an illegal value of 'fn'"))
 
     n.strata <- length(x)
+    if (n.strata >= 2 & is.null(strata) & !is.null(names(x))){
+        strata <- names(x)
+    }
 
     if (length(col) < n.strata) col <- rep(col, n.strata)
-    if (length(lty) < n.strata) lty <- rep(lty, n.strata)
+    if (length(lty) < n.strata) lty <- 1:n.strata
     
     yVal <- function(x){
         if (fn == "cum") return(cumsum(x))
-        if (fn %in% c("log", "loglog")) return(log(cumsum(x)))
+        if (fn %in% c("log", "loglog")){
+            y <- cumsum(x)
+            y[y <= 0] <- NA
+            return(y)
+        } ##return(log(cumsum(x)))
         n <- length(x)
         s <- numeric(n)
         s[1] <- 1 - x[1]
@@ -108,22 +136,13 @@ plot.hazdata <- function(x, strata = NULL,
     max.x <- max(x[[1]][, 1])
     min.x <- min(x[[1]][, 1])
 
-    if (fn == "loglog"){
-        max.x <- log(max.x)
-        if (min.x > 0){
-            min.x <- log(min.x)
-        }else{
-            lin.x <- log(min.x + 0.001)
-        }
-    }
-
-    max.y <- -1000 # What else :-)
-    min.y <- 0
+    max.y <- max(x[[1]][, 2]) # What else :-)
+    min.y <- min(x[[1]][, 2])
     for (i in 1:n.strata){
         x[[i]][, 2] <- yVal(x[[i]][, 2])
-        max.y <- max(c(max.y, x[[i]][, 2]))
-        min.y <- min(c(min.y, x[[i]][, 2]))
-        if (fn == "loglog") x[[i]][, 1] <- log(x[[i]][, 1])
+        max.y <- max(c(max.y, x[[i]][, 2]), na.rm = TRUE)
+        min.y <- min(c(min.y, x[[i]][, 2]), na.rm = TRUE)
+
         max.x <- max(c(max.x, x[[i]][, 1]))
         min.x <- min(c(min.x, x[[i]][, 1]))
     }
@@ -145,14 +164,25 @@ plot.hazdata <- function(x, strata = NULL,
             if (fn == "surv"){
                 x[[i]] <- rbind(c(x[[i]][1, 1], 1), x[[i]])
             }else{
-                x[[i]] <- rbind(c(x[[i]][1, 1], 0), x[[i]])
+                ##x[[i]] <- rbind(c(x[[i]][1, 1], 0), x[[i]])
             }
             ##x[[i]][, 1] <- c(x[[i]][1, 1], x[[i]][, 1])
         }
     }
     if (fig){
-        plot(x[[1]][, 1], x[[1]][, 2], type = "s",
-             xlim = xlim, ylim = ylim, col = col[1],
+        if (fn == "log") {
+            ##ylim <- NULL
+            loga <- "y"
+        }else if (fn == "loglog"){
+            loga <- "xy"
+            ##ylim <- NULL
+        }else{
+            loga <- ""
+        }
+        
+        plot(x[[1]][, 1], x[[1]][, 2], type = "s", log = loga,
+             xlim = xlim, ylim = ylim, 
+             col = col[1],
              xlab = xlab, ylab = ylab, main = main, lty = lty[1], ...)
         if (n.strata > 1){
             for (i in 2:n.strata){
@@ -170,4 +200,3 @@ plot.hazdata <- function(x, strata = NULL,
     }
     invisible(list(x = x, fn = fn))
 }
-
