@@ -132,11 +132,11 @@ weibreg <-
     dropx <- NULL
     
     if (length(strats)) {
-        temp <- untangle.specials(Terms, "strata", 1)
+        temp <- survival::untangle.specials(Terms, "strata", 1)
         dropx <- c(dropx, temp$terms)
         if (length(temp$vars) == 1) 
           strata.keep <- m[[temp$vars]]
-        else strata.keep <- strata(m[, temp$vars], shortlabel = TRUE)
+        else strata.keep <- survival::strata(m[, temp$vars], shortlabel = TRUE)
         strats <- as.numeric(strata.keep)
     }
     if (length(dropx)) 
@@ -323,7 +323,7 @@ weibreg <-
     fit$levels <- levels
     fit$formula <- formula(Terms)
     fit$call <- call
-    fit$events <- n.events 
+    fit$n.events <- n.events 
     ##class(fit) <- c("weibreg", "coxreg", "coxph")
     class(fit) <- c("weibreg", "phreg")
     fit$pfixed <- pfixed
